{
	modules => [qw(YAML)],
	modules_init => {
		YAML => {
		},
	},
}

